Learn R Programming

RDieHarder (version 0.1.0)

dieharder: Random numebr generator test suite

Description

The random package provides an interface to the dieharder suite of random number generators.

Usage

## S3 method for class 'dieharder':
   \method{print(x, ...)est="runs", psamples=100,
                               seed=0, verbose=FALSE, inputfile="", ntuple=5) 
   ## S3 method for class 'dieharder':
print(x, ...)
   ## S3 method for class 'dieharder':
summary(object, ...)
   ## S3 method for class 'dieharder':
plot(x, ...)
   dieharderGenerators()
   dieharderTests()

Arguments

Value

An object of class dieharder, which inherits from the class htest commonly used for test statistics is returned. It contains the membersp.valuefor the (Kuiper variant) of the Kolmogorov-Smirnov test of the null of a uniform distribution of test values generated by psamples tests of test using draws from rngdatathe vector of test statistics used for the Kolmogorov-Smirnov testmethodthe test method as returned by the dieharder librarydata.namea character vector describing the datageneratora text desciption of the generator as returned by the dieharder library

Details

The current list of generators can be generated dynamically using the dieharderGenerators() function. Entries with id below 200 are from the GNU Scientific Library, entries with id greater or equal to 200 and less than 400 are from Dieharder itself, entries with id greater or equal to 400 and less than 500 are from GNU R, entries with id greater or equal to 500 and less than 600 are hardware-based (which is system-dependent), and entries with id greater or equal to 600 are user-contributed.

The current list of tests can be generated dynamicall using the dieharderTests() function.

References

The dieharder source code and website at http://www.phy.duke.edu/~rgb/General/dieharder.php.

Examples

Run this code
## need to set this for the example to pass the R CMD check test
  .dieharder.generators <<- dieharderGenerators()
  dh <- dieharder("randu", "runs", seed=12345)
  dh
  summary(dh)
  plot(dh)

Run the code above in your browser using DataLab