Learn R Programming

RDieHarder (version 0.0.7)

dieharder: Random numebr generator test suite

Description

The random package provides an interface to the dieharder suite of random number generators.

Usage

## S3 method for class 'default':
dieharder(rng="mt19937", test="runs", psamples=100, seed=0, rngdraws=100000, verbose=FALSE) 
   ## S3 method for class 'dieharder':
print(x, ...)
   ## S3 method for class 'dieharder':
summary(object, ...)
   ## S3 method for class 'dieharder':
plot(x, ...)
   dieharderGenerators()

Arguments

Value

An object of class dieharder, which inherits from the class htest commonly used for test statistics is returned. It contains the membersp.valuefor the (Kuiper variant) of the Kolmogorov-Smirnov test of the null of a uniform distribution of test values generated by psamples tests of test using draws from rngdatathe vector of test statistics used for the Kolmogorov-Smirnov testmethodthe test method as returned by the dieharder librarydata.namea character vector describing the datageneratora text desciption of the generator as returned by the dieharder library

Details

The current list of generators (which can be generated dynamically using the dieharderGenerators() function) comprises borosh13, cmrg, coveyou, fishman18, fishman20, fishman2x, gfsr4, knuthran, knuthran2, knuthran2002, lecuyer21, minstd, mrg, mt19937, mt19937_1999, mt19937_1998, r250, ran0, ran1, ran2, ran3, rand, rand48, random128-bsd, random128-glibc2, random128-libc5, random256-bsd, random256-glibc2, random256-libc5, random32-bsd, random32-glibc2, random32-libc5, random64-bsd, random64-glibc2, random64-libc5, random8-bsd, random8-glibc2, random8-libc5, random-bsd, random-glibc2, random-libc5, randu, ranf, ranlux, ranlux389, ranlxd1, ranlxd2, ranlxs0, ranlxs1, ranlxs2, ranmar, slatec, taus, taus2, taus113, transputer, tt800, uni, uni32, vax, waterman14, zuf, dev/random, dev/urandom, empty, file_input, file_input_raw, ca, R_wichmann_hill, R_marsaglia_multic., R_super_duper, R_mersenne_twister, R_knuth_taocp, R_knuth_taocp2 .

The current list of tests comprises birthdays, operm5, rank_32x32, rank_6x8, bitstream, opso, oqso, dna, count_1s_stream, count_1s_byte, parking_lot, 2dsphere, 3dsphere, squeeze, sums, runs, craps, marsaglia_tsang_gcd, marsaglia_tsang_gorilla, rgb_timing, rgb_persist, rgb_bitdist, rgb_lmn, sts_monobit, sts_runs, sts_block

References

The dieharder source code and website at http://www.phy.duke.edu/~rgb/General/dieharder.php.

Examples

Run this code
## need to set this for the example to pass the R CMD check test
  .dieharder.generators <<- dieharderGenerators()
  dh <- dieharder("randu", "runs", seed=12345)
  dh
  summary(dh)
  plot(dh)

Run the code above in your browser using DataLab